==> blanco.plugin.pdf_0.0.6-src.zip: src/blanco/pdf/page/valueobject/BlancoPdfPageDef.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.pdf.page.valueobject;

import java.util.List;

import javax.xml.bind.annotation.XmlRootElement;

import blanco.pdf.form.valueobject.BlancoPdfFormDef;

/**
 * PDF y[WEo[IuWFNgB
 */
@XmlRootElement
public class BlancoPdfPageDef {
    /**
     * y[W̖O (ID)
     *
     * tB[h: [name]B
     */
    private String fName;

    /**
     * pbP[WB
     *
     * tB[h: [package]B
     * ftHg: ["noname"]B
     */
    private String fPackage = "noname";

    /**
     * p̉}[WB
     *
     * tB[h: [marginX]B
     * ftHg: [0f]B
     */
    private float fMarginX = 0f;

    /**
     * p̏c}[WB
     *
     * tB[h: [marginY]B
     * ftHg: [0f]B
     */
    private float fMarginY = 0f;

    /**
     * tB[h: [pitchX]B
     * ftHg: [7.2f]B
     */
    private float fPitchX = 7.2f;

    /**
     * tB[h: [pitchY]B
     * ftHg: [7.2f * 10 / 6]B
     */
    private float fPitchY = 7.2f * 10 / 6;

    /**
     * y[WBfalse ͏cBtrue ͉B
     *
     * tB[h: [rotate]B
     * ftHg: [false]B
     */
    private boolean fRotate = false;

    /**
     * JB
     *
     * tB[h: [column]B
     * ftHg: [30]B
     */
    private int fColumn = 30;

    /**
     * sB
     *
     * tB[h: [row]B
     * ftHg: [30]B
     */
    private int fRow = 30;

    /**
     * tB[h: [fontSize]B
     * ftHg: [12]B
     */
    private float fFontSize = 12;

    /**
     * ev[gBt@C (.pdf) ́Btemplate fBNgɓĂKvB
     *
     * tB[h: [template]B
     * ftHg: [null]B
     */
    private String fTemplate = null;

    /**
     * tH[B
     *
     * tB[h: [form]B
     * ftHg: [new blanco.pdf.form.valueobject.BlancoPdfFormDef()]B
     */
    private BlancoPdfFormDef fForm = new blanco.pdf.form.valueobject.BlancoPdfFormDef();

    /**
     * ڃXgB
     *
     * tB[h: [itemList]B
     * ftHg: [new java.util.ArrayList<blanco.pdf.page.valueobject.BlancoPdfItemDef>()]B
     */
    private List<blanco.pdf.page.valueobject.BlancoPdfItemDef> fItemList = new java.util.ArrayList<blanco.pdf.page.valueobject.BlancoPdfItemDef>();

    /**
     * tB[h [name] ̒lݒ肵܂B
     *
     * tB[h̐: [y[W̖O (ID)]B
     *
     * @param argName tB[h[name]ɐݒ肷lB
     */
    public void setName(final String argName) {
        fName = argName;
    }

    /**
     * tB[h [name] ̒l擾܂B
     *
     * tB[h̐: [y[W̖O (ID)]B
     *
     * @return tB[h[name]擾lB
     */
    public String getName() {
        return fName;
    }

    /**
     * tB[h [package] ̒lݒ肵܂B
     *
     * tB[h̐: [pbP[WB]B
     *
     * @param argPackage tB[h[package]ɐݒ肷lB
     */
    public void setPackage(final String argPackage) {
        fPackage = argPackage;
    }

    /**
     * tB[h [package] ̒l擾܂B
     *
     * tB[h̐: [pbP[WB]B
     * ftHg: ["noname"]B
     *
     * @return tB[h[package]擾lB
     */
    public String getPackage() {
        return fPackage;
    }

    /**
     * tB[h [marginX] ̒lݒ肵܂B
     *
     * tB[h̐: [p̉}[WB]B
     *
     * @param argMarginX tB[h[marginX]ɐݒ肷lB
     */
    public void setMarginX(final float argMarginX) {
        fMarginX = argMarginX;
    }

    /**
     * tB[h [marginX] ̒l擾܂B
     *
     * tB[h̐: [p̉}[WB]B
     * ftHg: [0f]B
     *
     * @return tB[h[marginX]擾lB
     */
    public float getMarginX() {
        return fMarginX;
    }

    /**
     * tB[h [marginY] ̒lݒ肵܂B
     *
     * tB[h̐: [p̏c}[WB]B
     *
     * @param argMarginY tB[h[marginY]ɐݒ肷lB
     */
    public void setMarginY(final float argMarginY) {
        fMarginY = argMarginY;
    }

    /**
     * tB[h [marginY] ̒l擾܂B
     *
     * tB[h̐: [p̏c}[WB]B
     * ftHg: [0f]B
     *
     * @return tB[h[marginY]擾lB
     */
    public float getMarginY() {
        return fMarginY;
    }

    /**
     * tB[h [pitchX] ̒lݒ肵܂B
     *
     * @param argPitchX tB[h[pitchX]ɐݒ肷lB
     */
    public void setPitchX(final float argPitchX) {
        fPitchX = argPitchX;
    }

    /**
     * tB[h [pitchX] ̒l擾܂B
     *
     * ftHg: [7.2f]B
     *
     * @return tB[h[pitchX]擾lB
     */
    public float getPitchX() {
        return fPitchX;
    }

    /**
     * tB[h [pitchY] ̒lݒ肵܂B
     *
     * @param argPitchY tB[h[pitchY]ɐݒ肷lB
     */
    public void setPitchY(final float argPitchY) {
        fPitchY = argPitchY;
    }

    /**
     * tB[h [pitchY] ̒l擾܂B
     *
     * ftHg: [7.2f * 10 / 6]B
     *
     * @return tB[h[pitchY]擾lB
     */
    public float getPitchY() {
        return fPitchY;
    }

    /**
     * tB[h [rotate] ̒lݒ肵܂B
     *
     * tB[h̐: [y[WBfalse ͏cBtrue ͉B]B
     *
     * @param argRotate tB[h[rotate]ɐݒ肷lB
     */
    public void setRotate(final boolean argRotate) {
        fRotate = argRotate;
    }

    /**
     * tB[h [rotate] ̒l擾܂B
     *
     * tB[h̐: [y[WBfalse ͏cBtrue ͉B]B
     * ftHg: [false]B
     *
     * @return tB[h[rotate]擾lB
     */
    public boolean getRotate() {
        return fRotate;
    }

    /**
     * tB[h [column] ̒lݒ肵܂B
     *
     * tB[h̐: [JB]B
     *
     * @param argColumn tB[h[column]ɐݒ肷lB
     */
    public void setColumn(final int argColumn) {
        fColumn = argColumn;
    }

    /**
     * tB[h [column] ̒l擾܂B
     *
     * tB[h̐: [JB]B
     * ftHg: [30]B
     *
     * @return tB[h[column]擾lB
     */
    public int getColumn() {
        return fColumn;
    }

    /**
     * tB[h [row] ̒lݒ肵܂B
     *
     * tB[h̐: [sB]B
     *
     * @param argRow tB[h[row]ɐݒ肷lB
     */
    public void setRow(final int argRow) {
        fRow = argRow;
    }

    /**
     * tB[h [row] ̒l擾܂B
     *
     * tB[h̐: [sB]B
     * ftHg: [30]B
     *
     * @return tB[h[row]擾lB
     */
    public int getRow() {
        return fRow;
    }

    /**
     * tB[h [fontSize] ̒lݒ肵܂B
     *
     * @param argFontSize tB[h[fontSize]ɐݒ肷lB
     */
    public void setFontSize(final float argFontSize) {
        fFontSize = argFontSize;
    }

    /**
     * tB[h [fontSize] ̒l擾܂B
     *
     * ftHg: [12]B
     *
     * @return tB[h[fontSize]擾lB
     */
    public float getFontSize() {
        return fFontSize;
    }

    /**
     * tB[h [template] ̒lݒ肵܂B
     *
     * tB[h̐: [ev[gBt@C (.pdf) ́Btemplate fBNgɓĂKvB]B
     *
     * @param argTemplate tB[h[template]ɐݒ肷lB
     */
    public void setTemplate(final String argTemplate) {
        fTemplate = argTemplate;
    }

    /**
     * tB[h [template] ̒l擾܂B
     *
     * tB[h̐: [ev[gBt@C (.pdf) ́Btemplate fBNgɓĂKvB]B
     * ftHg: [null]B
     *
     * @return tB[h[template]擾lB
     */
    public String getTemplate() {
        return fTemplate;
    }

    /**
     * tB[h [form] ̒lݒ肵܂B
     *
     * tB[h̐: [tH[B]B
     *
     * @param argForm tB[h[form]ɐݒ肷lB
     */
    public void setForm(final BlancoPdfFormDef argForm) {
        fForm = argForm;
    }

    /**
     * tB[h [form] ̒l擾܂B
     *
     * tB[h̐: [tH[B]B
     * ftHg: [new blanco.pdf.form.valueobject.BlancoPdfFormDef()]B
     *
     * @return tB[h[form]擾lB
     */
    public BlancoPdfFormDef getForm() {
        return fForm;
    }

    /**
     * tB[h [itemList] ̒lݒ肵܂B
     *
     * tB[h̐: [ڃXgB]B
     *
     * @param argItemList tB[h[itemList]ɐݒ肷lB
     */
    public void setItemList(final List<blanco.pdf.page.valueobject.BlancoPdfItemDef> argItemList) {
        fItemList = argItemList;
    }

    /**
     * tB[h [itemList] ̒l擾܂B
     *
     * tB[h̐: [ڃXgB]B
     * ftHg: [new java.util.ArrayList<blanco.pdf.page.valueobject.BlancoPdfItemDef>()]B
     *
     * @return tB[h[itemList]擾lB
     */
    public List<blanco.pdf.page.valueobject.BlancoPdfItemDef> getItemList() {
        return fItemList;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * <P>gp̒</P>
     * <UL>
     * <LI>IuWFNg̃V[͈͂̂ݕ񉻂̏ΏۂƂȂ܂B
     * <LI>IuWFNgzQƂĂꍇɂ́Ã\bh͎gȂłB
     * </UL>
     *
     * @return o[IuWFNg̕\B
     */
    @Override
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.pdf.page.valueobject.BlancoPdfPageDef[");
        buf.append("name=" + fName);
        buf.append(",package=" + fPackage);
        buf.append(",marginX=" + fMarginX);
        buf.append(",marginY=" + fMarginY);
        buf.append(",pitchX=" + fPitchX);
        buf.append(",pitchY=" + fPitchY);
        buf.append(",rotate=" + fRotate);
        buf.append(",column=" + fColumn);
        buf.append(",row=" + fRow);
        buf.append(",fontSize=" + fFontSize);
        buf.append(",template=" + fTemplate);
        buf.append(",form=" + fForm);
        buf.append(",itemList=" + fItemList);
        buf.append("]");
        return buf.toString();
    }
}

==> blanco.plugin.pdf_0.1.4-src.zip: src/blanco/pdf/page/valueobject/BlancoPdfPageDef.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.pdf.page.valueobject;

import java.util.List;

import javax.xml.bind.annotation.XmlRootElement;

import blanco.pdf.form.valueobject.BlancoPdfFormDef;

/**
 * PDF y[WEo[IuWFNgB
 */
@XmlRootElement
public class BlancoPdfPageDef {
    /**
     * y[W̖O (ID)
     *
     * tB[h: [name]B
     */
    private String fName;

    /**
     * pbP[WB
     *
     * tB[h: [package]B
     * ftHg: ["noname"]B
     */
    private String fPackage = "noname";

    /**
     * p̉}[WB
     *
     * tB[h: [marginX]B
     * ftHg: [0f]B
     */
    private float fMarginX = 0f;

    /**
     * p̏c}[WB
     *
     * tB[h: [marginY]B
     * ftHg: [0f]B
     */
    private float fMarginY = 0f;

    /**
     * tB[h: [pitchX]B
     * ftHg: [7.2f]B
     */
    private float fPitchX = 7.2f;

    /**
     * tB[h: [pitchY]B
     * ftHg: [7.2f * 10 / 6]B
     */
    private float fPitchY = 7.2f * 10 / 6;

    /**
     * y[WBfalse ͏cBtrue ͉B
     *
     * tB[h: [rotate]B
     * ftHg: [false]B
     */
    private boolean fRotate = false;

    /**
     * JB
     *
     * tB[h: [column]B
     * ftHg: [30]B
     */
    private int fColumn = 30;

    /**
     * sB
     *
     * tB[h: [row]B
     * ftHg: [30]B
     */
    private int fRow = 30;

    /**
     * tHgTCYB݂قƂǗpĂ܂B
     *
     * tB[h: [fontSize]B
     * ftHg: [12]B
     */
    private float fFontSize = 12;

    /**
     * ev[gBt@C (.pdf) ́Btemplate fBNgɓĂKvB
     *
     * tB[h: [template]B
     * ftHg: [null]B
     */
    private String fTemplate = null;

    /**
     * tH[B
     *
     * tB[h: [form]B
     * ftHg: [new blanco.pdf.form.valueobject.BlancoPdfFormDef()]B
     */
    private BlancoPdfFormDef fForm = new blanco.pdf.form.valueobject.BlancoPdfFormDef();

    /**
     * ڃXgB
     *
     * tB[h: [itemList]B
     * ftHg: [new java.util.ArrayList<blanco.pdf.page.valueobject.BlancoPdfItemDef>()]B
     */
    private List<blanco.pdf.page.valueobject.BlancoPdfItemDef> fItemList = new java.util.ArrayList<blanco.pdf.page.valueobject.BlancoPdfItemDef>();

    /**
     * ubÑXgBJԂڂŗpB
     *
     * tB[h: [blockList]B
     * ftHg: [new java.util.ArrayList<blanco.pdf.page.valueobject.BlancoPdfBlockDef>()]B
     */
    private List<blanco.pdf.page.valueobject.BlancoPdfBlockDef> fBlockList = new java.util.ArrayList<blanco.pdf.page.valueobject.BlancoPdfBlockDef>();

    /**
     * tB[h [name] ̒lݒ肵܂B
     *
     * tB[h̐: [y[W̖O (ID)]B
     *
     * @param argName tB[h[name]ɐݒ肷lB
     */
    public void setName(final String argName) {
        fName = argName;
    }

    /**
     * tB[h [name] ̒l擾܂B
     *
     * tB[h̐: [y[W̖O (ID)]B
     *
     * @return tB[h[name]擾lB
     */
    public String getName() {
        return fName;
    }

    /**
     * tB[h [package] ̒lݒ肵܂B
     *
     * tB[h̐: [pbP[WB]B
     *
     * @param argPackage tB[h[package]ɐݒ肷lB
     */
    public void setPackage(final String argPackage) {
        fPackage = argPackage;
    }

    /**
     * tB[h [package] ̒l擾܂B
     *
     * tB[h̐: [pbP[WB]B
     * ftHg: ["noname"]B
     *
     * @return tB[h[package]擾lB
     */
    public String getPackage() {
        return fPackage;
    }

    /**
     * tB[h [marginX] ̒lݒ肵܂B
     *
     * tB[h̐: [p̉}[WB]B
     *
     * @param argMarginX tB[h[marginX]ɐݒ肷lB
     */
    public void setMarginX(final float argMarginX) {
        fMarginX = argMarginX;
    }

    /**
     * tB[h [marginX] ̒l擾܂B
     *
     * tB[h̐: [p̉}[WB]B
     * ftHg: [0f]B
     *
     * @return tB[h[marginX]擾lB
     */
    public float getMarginX() {
        return fMarginX;
    }

    /**
     * tB[h [marginY] ̒lݒ肵܂B
     *
     * tB[h̐: [p̏c}[WB]B
     *
     * @param argMarginY tB[h[marginY]ɐݒ肷lB
     */
    public void setMarginY(final float argMarginY) {
        fMarginY = argMarginY;
    }

    /**
     * tB[h [marginY] ̒l擾܂B
     *
     * tB[h̐: [p̏c}[WB]B
     * ftHg: [0f]B
     *
     * @return tB[h[marginY]擾lB
     */
    public float getMarginY() {
        return fMarginY;
    }

    /**
     * tB[h [pitchX] ̒lݒ肵܂B
     *
     * @param argPitchX tB[h[pitchX]ɐݒ肷lB
     */
    public void setPitchX(final float argPitchX) {
        fPitchX = argPitchX;
    }

    /**
     * tB[h [pitchX] ̒l擾܂B
     *
     * ftHg: [7.2f]B
     *
     * @return tB[h[pitchX]擾lB
     */
    public float getPitchX() {
        return fPitchX;
    }

    /**
     * tB[h [pitchY] ̒lݒ肵܂B
     *
     * @param argPitchY tB[h[pitchY]ɐݒ肷lB
     */
    public void setPitchY(final float argPitchY) {
        fPitchY = argPitchY;
    }

    /**
     * tB[h [pitchY] ̒l擾܂B
     *
     * ftHg: [7.2f * 10 / 6]B
     *
     * @return tB[h[pitchY]擾lB
     */
    public float getPitchY() {
        return fPitchY;
    }

    /**
     * tB[h [rotate] ̒lݒ肵܂B
     *
     * tB[h̐: [y[WBfalse ͏cBtrue ͉B]B
     *
     * @param argRotate tB[h[rotate]ɐݒ肷lB
     */
    public void setRotate(final boolean argRotate) {
        fRotate = argRotate;
    }

    /**
     * tB[h [rotate] ̒l擾܂B
     *
     * tB[h̐: [y[WBfalse ͏cBtrue ͉B]B
     * ftHg: [false]B
     *
     * @return tB[h[rotate]擾lB
     */
    public boolean getRotate() {
        return fRotate;
    }

    /**
     * tB[h [column] ̒lݒ肵܂B
     *
     * tB[h̐: [JB]B
     *
     * @param argColumn tB[h[column]ɐݒ肷lB
     */
    public void setColumn(final int argColumn) {
        fColumn = argColumn;
    }

    /**
     * tB[h [column] ̒l擾܂B
     *
     * tB[h̐: [JB]B
     * ftHg: [30]B
     *
     * @return tB[h[column]擾lB
     */
    public int getColumn() {
        return fColumn;
    }

    /**
     * tB[h [row] ̒lݒ肵܂B
     *
     * tB[h̐: [sB]B
     *
     * @param argRow tB[h[row]ɐݒ肷lB
     */
    public void setRow(final int argRow) {
        fRow = argRow;
    }

    /**
     * tB[h [row] ̒l擾܂B
     *
     * tB[h̐: [sB]B
     * ftHg: [30]B
     *
     * @return tB[h[row]擾lB
     */
    public int getRow() {
        return fRow;
    }

    /**
     * tB[h [fontSize] ̒lݒ肵܂B
     *
     * tB[h̐: [tHgTCYB݂قƂǗpĂ܂B]B
     *
     * @param argFontSize tB[h[fontSize]ɐݒ肷lB
     */
    public void setFontSize(final float argFontSize) {
        fFontSize = argFontSize;
    }

    /**
     * tB[h [fontSize] ̒l擾܂B
     *
     * tB[h̐: [tHgTCYB݂قƂǗpĂ܂B]B
     * ftHg: [12]B
     *
     * @return tB[h[fontSize]擾lB
     */
    public float getFontSize() {
        return fFontSize;
    }

    /**
     * tB[h [template] ̒lݒ肵܂B
     *
     * tB[h̐: [ev[gBt@C (.pdf) ́Btemplate fBNgɓĂKvB]B
     *
     * @param argTemplate tB[h[template]ɐݒ肷lB
     */
    public void setTemplate(final String argTemplate) {
        fTemplate = argTemplate;
    }

    /**
     * tB[h [template] ̒l擾܂B
     *
     * tB[h̐: [ev[gBt@C (.pdf) ́Btemplate fBNgɓĂKvB]B
     * ftHg: [null]B
     *
     * @return tB[h[template]擾lB
     */
    public String getTemplate() {
        return fTemplate;
    }

    /**
     * tB[h [form] ̒lݒ肵܂B
     *
     * tB[h̐: [tH[B]B
     *
     * @param argForm tB[h[form]ɐݒ肷lB
     */
    public void setForm(final BlancoPdfFormDef argForm) {
        fForm = argForm;
    }

    /**
     * tB[h [form] ̒l擾܂B
     *
     * tB[h̐: [tH[B]B
     * ftHg: [new blanco.pdf.form.valueobject.BlancoPdfFormDef()]B
     *
     * @return tB[h[form]擾lB
     */
    public BlancoPdfFormDef getForm() {
        return fForm;
    }

    /**
     * tB[h [itemList] ̒lݒ肵܂B
     *
     * tB[h̐: [ڃXgB]B
     *
     * @param argItemList tB[h[itemList]ɐݒ肷lB
     */
    public void setItemList(final List<blanco.pdf.page.valueobject.BlancoPdfItemDef> argItemList) {
        fItemList = argItemList;
    }

    /**
     * tB[h [itemList] ̒l擾܂B
     *
     * tB[h̐: [ڃXgB]B
     * ftHg: [new java.util.ArrayList<blanco.pdf.page.valueobject.BlancoPdfItemDef>()]B
     *
     * @return tB[h[itemList]擾lB
     */
    public List<blanco.pdf.page.valueobject.BlancoPdfItemDef> getItemList() {
        return fItemList;
    }

    /**
     * tB[h [blockList] ̒lݒ肵܂B
     *
     * tB[h̐: [ubÑXgBJԂڂŗpB]B
     *
     * @param argBlockList tB[h[blockList]ɐݒ肷lB
     */
    public void setBlockList(final List<blanco.pdf.page.valueobject.BlancoPdfBlockDef> argBlockList) {
        fBlockList = argBlockList;
    }

    /**
     * tB[h [blockList] ̒l擾܂B
     *
     * tB[h̐: [ubÑXgBJԂڂŗpB]B
     * ftHg: [new java.util.ArrayList<blanco.pdf.page.valueobject.BlancoPdfBlockDef>()]B
     *
     * @return tB[h[blockList]擾lB
     */
    public List<blanco.pdf.page.valueobject.BlancoPdfBlockDef> getBlockList() {
        return fBlockList;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * <P>gp̒</P>
     * <UL>
     * <LI>IuWFNg̃V[͈͂̂ݕ񉻂̏ΏۂƂȂ܂B
     * <LI>IuWFNgzQƂĂꍇɂ́Ã\bh͎gȂłB
     * </UL>
     *
     * @return o[IuWFNg̕\B
     */
    @Override
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.pdf.page.valueobject.BlancoPdfPageDef[");
        buf.append("name=" + fName);
        buf.append(",package=" + fPackage);
        buf.append(",marginX=" + fMarginX);
        buf.append(",marginY=" + fMarginY);
        buf.append(",pitchX=" + fPitchX);
        buf.append(",pitchY=" + fPitchY);
        buf.append(",rotate=" + fRotate);
        buf.append(",column=" + fColumn);
        buf.append(",row=" + fRow);
        buf.append(",fontSize=" + fFontSize);
        buf.append(",template=" + fTemplate);
        buf.append(",form=" + fForm);
        buf.append(",itemList=" + fItemList);
        buf.append(",blockList=" + fBlockList);
        buf.append("]");
        return buf.toString();
    }
}
